<?php

namespace Drupal\forgot_username\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Mail\MailManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

class ForgotUsernameForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['email_address'] = array(
      '#type' => 'textfield',
      '#title' => t('Your e-mail address'),
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Request Username'),
    );
    $form['#submit'][] = 'forgot_username_form_submit';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user.username';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableNames() {
    return 'forgot_username';
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $email = $form_state->getValue('email_address');
    $user = db_query("SELECT name FROM users_field_data WHERE mail=:mail",[':mail' => $email])->fetchField();
    if (!\Drupal::service('email.validator')->isValid($email)) {
      $form_state->setErrorByName("email_address", "The e-mail address is not valid.");
    }
    if (!$user) {
      $form_state->setErrorByName("email_address", "There is no account with that e-mail address.");
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $email = $form_state->getValue('email_address');
    \Drupal::state()->set('forgot_username_mail', $email);
    $mailMgr = \Drupal::service('plugin.manager.mail');
    $mailMgr->mail('forgot_username', 'notice', $form_state->getValue('email_address'), $language->language, $params);
    drupal_set_message(t('Your username has been e-mailed to the address specified. The e-mail might end up in spam folder, so please check there before complaining.'));
  }
}
